Documentation
¶
Index ¶
- Variables
- func RegisterBooksServiceServer(s grpc.ServiceRegistrar, srv BooksServiceServer)
- type Book
- func (*Book) Descriptor() ([]byte, []int)deprecated
- func (x *Book) GetCreatedAt() int64
- func (x *Book) GetCreatedBy() string
- func (x *Book) GetDescription() string
- func (x *Book) GetId() string
- func (x *Book) GetName() string
- func (x *Book) GetQuantity() int64
- func (x *Book) GetUpdatedAt() int64
- func (*Book) ProtoMessage()
- func (x *Book) ProtoReflect() protoreflect.Message
- func (x *Book) Reset()
- func (x *Book) String() string
- type BookUpdate
- func (*BookUpdate) Descriptor() ([]byte, []int)deprecated
- func (x *BookUpdate) GetDescription() string
- func (x *BookUpdate) GetId() string
- func (x *BookUpdate) GetName() string
- func (x *BookUpdate) GetQuantity() int64
- func (*BookUpdate) ProtoMessage()
- func (x *BookUpdate) ProtoReflect() protoreflect.Message
- func (x *BookUpdate) Reset()
- func (x *BookUpdate) String() string
- type BooksServiceClient
- type BooksServiceServer
- type CreateBookRequest
- func (*CreateBookRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateBookRequest) GetCreatedBy() string
- func (x *CreateBookRequest) GetDescription() string
- func (x *CreateBookRequest) GetName() string
- func (x *CreateBookRequest) GetQuantity() int64
- func (*CreateBookRequest) ProtoMessage()
- func (x *CreateBookRequest) ProtoReflect() protoreflect.Message
- func (x *CreateBookRequest) Reset()
- func (x *CreateBookRequest) String() string
- type CreateBookResponse
- func (*CreateBookResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateBookResponse) GetCode() int64
- func (x *CreateBookResponse) GetMessage() string
- func (*CreateBookResponse) ProtoMessage()
- func (x *CreateBookResponse) ProtoReflect() protoreflect.Message
- func (x *CreateBookResponse) Reset()
- func (x *CreateBookResponse) String() string
- type DeleteBookRequest
- type DeleteBookResponse
- func (*DeleteBookResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteBookResponse) GetCode() int64
- func (x *DeleteBookResponse) GetMessage() string
- func (*DeleteBookResponse) ProtoMessage()
- func (x *DeleteBookResponse) ProtoReflect() protoreflect.Message
- func (x *DeleteBookResponse) Reset()
- func (x *DeleteBookResponse) String() string
- type FetchAllBooksRequest
- type FetchAllBooksResponse
- func (*FetchAllBooksResponse) Descriptor() ([]byte, []int)deprecated
- func (x *FetchAllBooksResponse) GetCode() int64
- func (x *FetchAllBooksResponse) GetData() *FetchAllBooksResponseData
- func (x *FetchAllBooksResponse) GetMessage() string
- func (*FetchAllBooksResponse) ProtoMessage()
- func (x *FetchAllBooksResponse) ProtoReflect() protoreflect.Message
- func (x *FetchAllBooksResponse) Reset()
- func (x *FetchAllBooksResponse) String() string
- type FetchAllBooksResponseData
- func (*FetchAllBooksResponseData) Descriptor() ([]byte, []int)deprecated
- func (x *FetchAllBooksResponseData) GetBooks() []*Book
- func (*FetchAllBooksResponseData) ProtoMessage()
- func (x *FetchAllBooksResponseData) ProtoReflect() protoreflect.Message
- func (x *FetchAllBooksResponseData) Reset()
- func (x *FetchAllBooksResponseData) String() string
- type FetchBookByIdRequest
- func (*FetchBookByIdRequest) Descriptor() ([]byte, []int)deprecated
- func (x *FetchBookByIdRequest) GetId() string
- func (*FetchBookByIdRequest) ProtoMessage()
- func (x *FetchBookByIdRequest) ProtoReflect() protoreflect.Message
- func (x *FetchBookByIdRequest) Reset()
- func (x *FetchBookByIdRequest) String() string
- type FetchBookByIdResponse
- func (*FetchBookByIdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *FetchBookByIdResponse) GetBook() *Book
- func (x *FetchBookByIdResponse) GetCode() int64
- func (x *FetchBookByIdResponse) GetMessage() string
- func (*FetchBookByIdResponse) ProtoMessage()
- func (x *FetchBookByIdResponse) ProtoReflect() protoreflect.Message
- func (x *FetchBookByIdResponse) Reset()
- func (x *FetchBookByIdResponse) String() string
- type UnimplementedBooksServiceServer
- func (UnimplementedBooksServiceServer) Create(context.Context, *CreateBookRequest) (*CreateBookResponse, error)
- func (UnimplementedBooksServiceServer) DeleteById(context.Context, *DeleteBookRequest) (*DeleteBookResponse, error)
- func (UnimplementedBooksServiceServer) FetchAll(context.Context, *FetchAllBooksRequest) (*FetchAllBooksResponse, error)
- func (UnimplementedBooksServiceServer) FetchById(context.Context, *FetchBookByIdRequest) (*FetchBookByIdResponse, error)
- func (UnimplementedBooksServiceServer) Update(context.Context, *UpdateBookRequest) (*UpdateBookResponse, error)
- type UnsafeBooksServiceServer
- type UpdateBookRequest
- type UpdateBookResponse
- func (*UpdateBookResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateBookResponse) GetBook() *Book
- func (x *UpdateBookResponse) GetCode() int64
- func (x *UpdateBookResponse) GetMessage() string
- func (*UpdateBookResponse) ProtoMessage()
- func (x *UpdateBookResponse) ProtoReflect() protoreflect.Message
- func (x *UpdateBookResponse) Reset()
- func (x *UpdateBookResponse) String() string
Constants ¶
This section is empty.
Variables ¶
var BooksService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "books.BooksService", HandlerType: (*BooksServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "FetchAll", Handler: _BooksService_FetchAll_Handler, }, { MethodName: "Create", Handler: _BooksService_Create_Handler, }, { MethodName: "FetchById", Handler: _BooksService_FetchById_Handler, }, { MethodName: "Update", Handler: _BooksService_Update_Handler, }, { MethodName: "DeleteById", Handler: _BooksService_DeleteById_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "book.proto", }
BooksService_ServiceDesc is the grpc.ServiceDesc for BooksService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_book_proto protoreflect.FileDescriptor
Functions ¶
func RegisterBooksServiceServer ¶
func RegisterBooksServiceServer(s grpc.ServiceRegistrar, srv BooksServiceServer)
Types ¶
type Book ¶
type Book struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
CreatedBy string `protobuf:"bytes,2,opt,name=created_by,json=createdBy,proto3" json:"created_by,omitempty"`
Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
Description string `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
Quantity int64 `protobuf:"varint,5,opt,name=quantity,proto3" json:"quantity,omitempty"`
CreatedAt int64 `protobuf:"varint,6,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
UpdatedAt int64 `protobuf:"varint,7,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
// contains filtered or unexported fields
}
func (*Book) Descriptor
deprecated
func (*Book) GetCreatedAt ¶
func (*Book) GetCreatedBy ¶
func (*Book) GetDescription ¶
func (*Book) GetQuantity ¶
func (*Book) GetUpdatedAt ¶
func (*Book) ProtoMessage ¶
func (*Book) ProtoMessage()
func (*Book) ProtoReflect ¶
func (x *Book) ProtoReflect() protoreflect.Message
type BookUpdate ¶
type BookUpdate struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
Quantity int64 `protobuf:"varint,4,opt,name=quantity,proto3" json:"quantity,omitempty"`
// contains filtered or unexported fields
}
func (*BookUpdate) Descriptor
deprecated
func (*BookUpdate) Descriptor() ([]byte, []int)
Deprecated: Use BookUpdate.ProtoReflect.Descriptor instead.
func (*BookUpdate) GetDescription ¶
func (x *BookUpdate) GetDescription() string
func (*BookUpdate) GetId ¶
func (x *BookUpdate) GetId() string
func (*BookUpdate) GetName ¶
func (x *BookUpdate) GetName() string
func (*BookUpdate) GetQuantity ¶
func (x *BookUpdate) GetQuantity() int64
func (*BookUpdate) ProtoMessage ¶
func (*BookUpdate) ProtoMessage()
func (*BookUpdate) ProtoReflect ¶
func (x *BookUpdate) ProtoReflect() protoreflect.Message
func (*BookUpdate) Reset ¶
func (x *BookUpdate) Reset()
func (*BookUpdate) String ¶
func (x *BookUpdate) String() string
type BooksServiceClient ¶
type BooksServiceClient interface {
FetchAll(ctx context.Context, in *FetchAllBooksRequest, opts ...grpc.CallOption) (*FetchAllBooksResponse, error)
Create(ctx context.Context, in *CreateBookRequest, opts ...grpc.CallOption) (*CreateBookResponse, error)
FetchById(ctx context.Context, in *FetchBookByIdRequest, opts ...grpc.CallOption) (*FetchBookByIdResponse, error)
Update(ctx context.Context, in *UpdateBookRequest, opts ...grpc.CallOption) (*UpdateBookResponse, error)
DeleteById(ctx context.Context, in *DeleteBookRequest, opts ...grpc.CallOption) (*DeleteBookResponse, error)
}
BooksServiceClient is the client API for BooksService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewBooksServiceClient ¶
func NewBooksServiceClient(cc grpc.ClientConnInterface) BooksServiceClient
type BooksServiceServer ¶
type BooksServiceServer interface {
FetchAll(context.Context, *FetchAllBooksRequest) (*FetchAllBooksResponse, error)
Create(context.Context, *CreateBookRequest) (*CreateBookResponse, error)
FetchById(context.Context, *FetchBookByIdRequest) (*FetchBookByIdResponse, error)
Update(context.Context, *UpdateBookRequest) (*UpdateBookResponse, error)
DeleteById(context.Context, *DeleteBookRequest) (*DeleteBookResponse, error)
// contains filtered or unexported methods
}
BooksServiceServer is the server API for BooksService service. All implementations must embed UnimplementedBooksServiceServer for forward compatibility
type CreateBookRequest ¶
type CreateBookRequest struct {
CreatedBy string `protobuf:"bytes,1,opt,name=created_by,json=createdBy,proto3" json:"created_by,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
Quantity int64 `protobuf:"varint,4,opt,name=quantity,proto3" json:"quantity,omitempty"`
// contains filtered or unexported fields
}
func (*CreateBookRequest) Descriptor
deprecated
func (*CreateBookRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateBookRequest.ProtoReflect.Descriptor instead.
func (*CreateBookRequest) GetCreatedBy ¶
func (x *CreateBookRequest) GetCreatedBy() string
func (*CreateBookRequest) GetDescription ¶
func (x *CreateBookRequest) GetDescription() string
func (*CreateBookRequest) GetName ¶
func (x *CreateBookRequest) GetName() string
func (*CreateBookRequest) GetQuantity ¶
func (x *CreateBookRequest) GetQuantity() int64
func (*CreateBookRequest) ProtoMessage ¶
func (*CreateBookRequest) ProtoMessage()
func (*CreateBookRequest) ProtoReflect ¶
func (x *CreateBookRequest) ProtoReflect() protoreflect.Message
func (*CreateBookRequest) Reset ¶
func (x *CreateBookRequest) Reset()
func (*CreateBookRequest) String ¶
func (x *CreateBookRequest) String() string
type CreateBookResponse ¶
type CreateBookResponse struct {
Code int64 `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*CreateBookResponse) Descriptor
deprecated
func (*CreateBookResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateBookResponse.ProtoReflect.Descriptor instead.
func (*CreateBookResponse) GetCode ¶
func (x *CreateBookResponse) GetCode() int64
func (*CreateBookResponse) GetMessage ¶
func (x *CreateBookResponse) GetMessage() string
func (*CreateBookResponse) ProtoMessage ¶
func (*CreateBookResponse) ProtoMessage()
func (*CreateBookResponse) ProtoReflect ¶
func (x *CreateBookResponse) ProtoReflect() protoreflect.Message
func (*CreateBookResponse) Reset ¶
func (x *CreateBookResponse) Reset()
func (*CreateBookResponse) String ¶
func (x *CreateBookResponse) String() string
type DeleteBookRequest ¶
type DeleteBookRequest struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteBookRequest) Descriptor
deprecated
func (*DeleteBookRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteBookRequest.ProtoReflect.Descriptor instead.
func (*DeleteBookRequest) GetId ¶
func (x *DeleteBookRequest) GetId() string
func (*DeleteBookRequest) ProtoMessage ¶
func (*DeleteBookRequest) ProtoMessage()
func (*DeleteBookRequest) ProtoReflect ¶
func (x *DeleteBookRequest) ProtoReflect() protoreflect.Message
func (*DeleteBookRequest) Reset ¶
func (x *DeleteBookRequest) Reset()
func (*DeleteBookRequest) String ¶
func (x *DeleteBookRequest) String() string
type DeleteBookResponse ¶
type DeleteBookResponse struct {
Code int64 `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteBookResponse) Descriptor
deprecated
func (*DeleteBookResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteBookResponse.ProtoReflect.Descriptor instead.
func (*DeleteBookResponse) GetCode ¶
func (x *DeleteBookResponse) GetCode() int64
func (*DeleteBookResponse) GetMessage ¶
func (x *DeleteBookResponse) GetMessage() string
func (*DeleteBookResponse) ProtoMessage ¶
func (*DeleteBookResponse) ProtoMessage()
func (*DeleteBookResponse) ProtoReflect ¶
func (x *DeleteBookResponse) ProtoReflect() protoreflect.Message
func (*DeleteBookResponse) Reset ¶
func (x *DeleteBookResponse) Reset()
func (*DeleteBookResponse) String ¶
func (x *DeleteBookResponse) String() string
type FetchAllBooksRequest ¶
type FetchAllBooksRequest struct {
// contains filtered or unexported fields
}
func (*FetchAllBooksRequest) Descriptor
deprecated
func (*FetchAllBooksRequest) Descriptor() ([]byte, []int)
Deprecated: Use FetchAllBooksRequest.ProtoReflect.Descriptor instead.
func (*FetchAllBooksRequest) ProtoMessage ¶
func (*FetchAllBooksRequest) ProtoMessage()
func (*FetchAllBooksRequest) ProtoReflect ¶
func (x *FetchAllBooksRequest) ProtoReflect() protoreflect.Message
func (*FetchAllBooksRequest) Reset ¶
func (x *FetchAllBooksRequest) Reset()
func (*FetchAllBooksRequest) String ¶
func (x *FetchAllBooksRequest) String() string
type FetchAllBooksResponse ¶
type FetchAllBooksResponse struct {
Code int64 `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
Data *FetchAllBooksResponseData `protobuf:"bytes,3,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
func (*FetchAllBooksResponse) Descriptor
deprecated
func (*FetchAllBooksResponse) Descriptor() ([]byte, []int)
Deprecated: Use FetchAllBooksResponse.ProtoReflect.Descriptor instead.
func (*FetchAllBooksResponse) GetCode ¶
func (x *FetchAllBooksResponse) GetCode() int64
func (*FetchAllBooksResponse) GetData ¶
func (x *FetchAllBooksResponse) GetData() *FetchAllBooksResponseData
func (*FetchAllBooksResponse) GetMessage ¶
func (x *FetchAllBooksResponse) GetMessage() string
func (*FetchAllBooksResponse) ProtoMessage ¶
func (*FetchAllBooksResponse) ProtoMessage()
func (*FetchAllBooksResponse) ProtoReflect ¶
func (x *FetchAllBooksResponse) ProtoReflect() protoreflect.Message
func (*FetchAllBooksResponse) Reset ¶
func (x *FetchAllBooksResponse) Reset()
func (*FetchAllBooksResponse) String ¶
func (x *FetchAllBooksResponse) String() string
type FetchAllBooksResponseData ¶
type FetchAllBooksResponseData struct {
Books []*Book `protobuf:"bytes,1,rep,name=books,proto3" json:"books,omitempty"`
// contains filtered or unexported fields
}
func (*FetchAllBooksResponseData) Descriptor
deprecated
func (*FetchAllBooksResponseData) Descriptor() ([]byte, []int)
Deprecated: Use FetchAllBooksResponseData.ProtoReflect.Descriptor instead.
func (*FetchAllBooksResponseData) GetBooks ¶
func (x *FetchAllBooksResponseData) GetBooks() []*Book
func (*FetchAllBooksResponseData) ProtoMessage ¶
func (*FetchAllBooksResponseData) ProtoMessage()
func (*FetchAllBooksResponseData) ProtoReflect ¶
func (x *FetchAllBooksResponseData) ProtoReflect() protoreflect.Message
func (*FetchAllBooksResponseData) Reset ¶
func (x *FetchAllBooksResponseData) Reset()
func (*FetchAllBooksResponseData) String ¶
func (x *FetchAllBooksResponseData) String() string
type FetchBookByIdRequest ¶
type FetchBookByIdRequest struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*FetchBookByIdRequest) Descriptor
deprecated
func (*FetchBookByIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use FetchBookByIdRequest.ProtoReflect.Descriptor instead.
func (*FetchBookByIdRequest) GetId ¶
func (x *FetchBookByIdRequest) GetId() string
func (*FetchBookByIdRequest) ProtoMessage ¶
func (*FetchBookByIdRequest) ProtoMessage()
func (*FetchBookByIdRequest) ProtoReflect ¶
func (x *FetchBookByIdRequest) ProtoReflect() protoreflect.Message
func (*FetchBookByIdRequest) Reset ¶
func (x *FetchBookByIdRequest) Reset()
func (*FetchBookByIdRequest) String ¶
func (x *FetchBookByIdRequest) String() string
type FetchBookByIdResponse ¶
type FetchBookByIdResponse struct {
Code int64 `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
Book *Book `protobuf:"bytes,3,opt,name=book,proto3" json:"book,omitempty"`
// contains filtered or unexported fields
}
func (*FetchBookByIdResponse) Descriptor
deprecated
func (*FetchBookByIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use FetchBookByIdResponse.ProtoReflect.Descriptor instead.
func (*FetchBookByIdResponse) GetBook ¶
func (x *FetchBookByIdResponse) GetBook() *Book
func (*FetchBookByIdResponse) GetCode ¶
func (x *FetchBookByIdResponse) GetCode() int64
func (*FetchBookByIdResponse) GetMessage ¶
func (x *FetchBookByIdResponse) GetMessage() string
func (*FetchBookByIdResponse) ProtoMessage ¶
func (*FetchBookByIdResponse) ProtoMessage()
func (*FetchBookByIdResponse) ProtoReflect ¶
func (x *FetchBookByIdResponse) ProtoReflect() protoreflect.Message
func (*FetchBookByIdResponse) Reset ¶
func (x *FetchBookByIdResponse) Reset()
func (*FetchBookByIdResponse) String ¶
func (x *FetchBookByIdResponse) String() string
type UnimplementedBooksServiceServer ¶
type UnimplementedBooksServiceServer struct {
}
UnimplementedBooksServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedBooksServiceServer) Create ¶
func (UnimplementedBooksServiceServer) Create(context.Context, *CreateBookRequest) (*CreateBookResponse, error)
func (UnimplementedBooksServiceServer) DeleteById ¶
func (UnimplementedBooksServiceServer) DeleteById(context.Context, *DeleteBookRequest) (*DeleteBookResponse, error)
func (UnimplementedBooksServiceServer) FetchAll ¶
func (UnimplementedBooksServiceServer) FetchAll(context.Context, *FetchAllBooksRequest) (*FetchAllBooksResponse, error)
func (UnimplementedBooksServiceServer) FetchById ¶
func (UnimplementedBooksServiceServer) FetchById(context.Context, *FetchBookByIdRequest) (*FetchBookByIdResponse, error)
func (UnimplementedBooksServiceServer) Update ¶
func (UnimplementedBooksServiceServer) Update(context.Context, *UpdateBookRequest) (*UpdateBookResponse, error)
type UnsafeBooksServiceServer ¶
type UnsafeBooksServiceServer interface {
// contains filtered or unexported methods
}
UnsafeBooksServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BooksServiceServer will result in compilation errors.
type UpdateBookRequest ¶
type UpdateBookRequest struct {
Book *BookUpdate `protobuf:"bytes,1,opt,name=book,proto3" json:"book,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateBookRequest) Descriptor
deprecated
func (*UpdateBookRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateBookRequest.ProtoReflect.Descriptor instead.
func (*UpdateBookRequest) GetBook ¶
func (x *UpdateBookRequest) GetBook() *BookUpdate
func (*UpdateBookRequest) ProtoMessage ¶
func (*UpdateBookRequest) ProtoMessage()
func (*UpdateBookRequest) ProtoReflect ¶
func (x *UpdateBookRequest) ProtoReflect() protoreflect.Message
func (*UpdateBookRequest) Reset ¶
func (x *UpdateBookRequest) Reset()
func (*UpdateBookRequest) String ¶
func (x *UpdateBookRequest) String() string
type UpdateBookResponse ¶
type UpdateBookResponse struct {
Code int64 `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
Book *Book `protobuf:"bytes,3,opt,name=book,proto3" json:"book,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateBookResponse) Descriptor
deprecated
func (*UpdateBookResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateBookResponse.ProtoReflect.Descriptor instead.
func (*UpdateBookResponse) GetBook ¶
func (x *UpdateBookResponse) GetBook() *Book
func (*UpdateBookResponse) GetCode ¶
func (x *UpdateBookResponse) GetCode() int64
func (*UpdateBookResponse) GetMessage ¶
func (x *UpdateBookResponse) GetMessage() string
func (*UpdateBookResponse) ProtoMessage ¶
func (*UpdateBookResponse) ProtoMessage()
func (*UpdateBookResponse) ProtoReflect ¶
func (x *UpdateBookResponse) ProtoReflect() protoreflect.Message
func (*UpdateBookResponse) Reset ¶
func (x *UpdateBookResponse) Reset()
func (*UpdateBookResponse) String ¶
func (x *UpdateBookResponse) String() string